package com.ruoyi.frequency.klkwithdrawalrecord.service;

import java.util.List;
import com.ruoyi.frequency.klkwithdrawalrecord.entity.KlkWithdrawalRecord;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 卡拉卡平台提现记录Service接口
 * 
 * @author liwenlong
 * @date 2024-05-07
 */
public interface KlkWithdrawalRecordService extends IService<KlkWithdrawalRecord>
{
    /**
     * 查询卡拉卡平台提现记录
     * 
     * @param id 卡拉卡平台提现记录主键
     * @return 卡拉卡平台提现记录
     */
    public KlkWithdrawalRecord selectKlkWithdrawalRecordById(Long id);

    /**
     * 查询卡拉卡平台提现记录列表
     * 
     * @param klkWithdrawalRecord 卡拉卡平台提现记录
     * @return 卡拉卡平台提现记录集合
     */
    public List<KlkWithdrawalRecord> selectKlkWithdrawalRecordList(KlkWithdrawalRecord klkWithdrawalRecord);

    /**
     * 新增卡拉卡平台提现记录
     * 
     * @param klkWithdrawalRecord 卡拉卡平台提现记录
     * @return 结果
     */
    public int insertKlkWithdrawalRecord(KlkWithdrawalRecord klkWithdrawalRecord);

    /**
     * 修改卡拉卡平台提现记录
     * 
     * @param klkWithdrawalRecord 卡拉卡平台提现记录
     * @return 结果
     */
    public int updateKlkWithdrawalRecord(KlkWithdrawalRecord klkWithdrawalRecord);

    /**
     * 批量删除卡拉卡平台提现记录
     * 
     * @param ids 需要删除的卡拉卡平台提现记录主键集合
     * @return 结果
     */
    public int deleteKlkWithdrawalRecordByIds(Long[] ids,Integer delFlag);

}
